from setuptools import setup

setup(
    name='notifly_client',
    author='Felipe Lacerda',
    email='fegolac@gmail.com',
    packages=['notifly_client'],
    include_package_data=True,
    version="0.0.3",
    python_requires=">=3.7",
    description="Bindings for the Notifly API",
)
